/**
 * @param {Record<string, string>} attributes
 * @param {string} property
 * @returns {string}
 */
export function caseInsensitiveTransform(attributes: Record<string, string>, property: string): string;
