/**
 * @param {Record<string, string>} attributes
 * @param {string} attribute
 * @returns {string}
 */
export function caseSensitiveTransform(attributes: Record<string, string>, attribute: string): string;
