/**
 * @param {Schema[]} definitions
 * @param {string} [space]
 * @returns {Schema}
 */
export function merge(definitions: Schema[], space?: string | undefined): Schema;
export type Properties = import('./schema.js').Properties;
export type Normal = import('./schema.js').Normal;
import { Schema } from './schema.js';
